@@ -2,11 +2,11 @@ mod algorithm;
 mod cells_grid;
 mod clustering;
 mod counting_tree;
-mod hyperparameters;
+mod hyperparams;
 
 pub use algorithm::*;
 pub use clustering::AppxDbscanLabeler;
-pub use hyperparameters::*;
+pub use hyperparams::*;
 
 #[cfg(test)]
 mod tests;
